{
    "$graph": [
        {
            "class": "Workflow",
            "label": "bam_readcount workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/min_mapping_quality"
                },
                {
                    "type": "string",
                    "id": "#main/reference_fasta"
                },
                {
                    "type": "string",
                    "id": "#main/sample"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/bam_readcount/bam"
                        },
                        {
                            "source": "#main/min_base_quality",
                            "id": "#main/bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#main/min_mapping_quality",
                            "id": "#main/bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#main/sample",
                            "id": "#main/bam_readcount/sample"
                        },
                        {
                            "source": "#main/decompose_variants/decomposed_vcf",
                            "id": "#main/bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/bam_readcount/snv_bam_readcount_tsv",
                        "#main/bam_readcount/indel_bam_readcount_tsv"
                    ],
                    "id": "#main/bam_readcount"
                },
                {
                    "run": "#vt_decompose.cwl",
                    "in": [
                        {
                            "source": "#main/normalize_variants/normalized_vcf",
                            "id": "#main/decompose_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/decompose_variants/decomposed_vcf"
                    ],
                    "id": "#main/decompose_variants"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/normalize_variants/reference"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/normalize_variants/normalized_vcf"
                    ],
                    "id": "#main/normalize_variants"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/bam_readcount/indel_bam_readcount_tsv",
                    "id": "#main/indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/decompose_variants/decomposed_vcf",
                    "id": "#main/normalized_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bam_readcount/snv_bam_readcount_tsv",
                    "id": "#main/snv_bam_readcount_tsv"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "run bam-readcount",
            "baseCommand": [
                "/usr/bin/python",
                "/usr/bin/bam_readcount_helper.py"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bam_readcount_helper-cwl:1.0.0"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -3
                }
            ],
            "stdout": "$(inputs.sample)_bam_readcount.tsv",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -4
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#bam_readcount.cwl/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#bam_readcount.cwl/min_mapping_quality"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -5
                    },
                    "id": "#bam_readcount.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -6
                    },
                    "id": "#bam_readcount.cwl/sample"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -7
                    },
                    "id": "#bam_readcount.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample)_bam_readcount_indel.tsv"
                    },
                    "id": "#bam_readcount.cwl/indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample)_bam_readcount_snv.tsv"
                    },
                    "id": "#bam_readcount.cwl/snv_bam_readcount_tsv"
                }
            ],
            "id": "#bam_readcount.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "run vt decompose",
            "baseCommand": [
                "vt",
                "decompose"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/vt:0.57721--hf74b74d_1"
                }
            ],
            "arguments": [
                "-s",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/decomposed.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vt_decompose.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "decomposed.vcf.gz"
                    },
                    "id": "#vt_decompose.cwl/decomposed_vcf"
                }
            ],
            "id": "#vt_decompose.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
